<a id="mypy-boto3-rds"></a>

# mypy-boto3-rds

[![PyPI - mypy-boto3-rds](https://img.shields.io/pypi/v/mypy-boto3-rds.svg?color=blue)](https://pypi.org/project/mypy-boto3-rds)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-rds.svg?color=blue)](https://pypi.org/project/mypy-boto3-rds)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/mypy-boto3-rds?color=blue)](https://pypistats.org/packages/mypy-boto3-rds)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.RDS 1.26.9](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds.html#RDS)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.11.10](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-rds docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rds/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-rds](#mypy-boto3-rds)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
    - [From conda-forge](#from-conda-forge)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `RDS`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `boto3-stubs` for `RDS` service.

```bash
# install with boto3 type annotations
python -m pip install 'boto3-stubs[rds]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'boto3-stubs-lite[rds]'


# standalone installation
python -m pip install mypy-boto3-rds
```

<a id="from-conda-forge"></a>

### From conda-forge

Installing `mypy-boto3-rds` from the `conda-forge` channel can be achieved by
adding `conda-forge` to your channels with:

```bash
conda config --add channels conda-forge
conda config --set channel_priority strict
```

Once the `conda-forge` channel has been enabled, `mypy-boto3-rds` can be
installed with:

```bash
conda install mypy-boto3-rds
```

It is possible to list all of the versions of `mypy-boto3-rds` available on
your platform with:

```bash
conda search mypy-boto3-rds --channel conda-forge
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y mypy-boto3-rds
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto3-stubs[rds]` in your environment:

```bash
python -m pip install 'boto3-stubs[rds]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `boto3-stubs-lite[rds]` in your environment:

```bash
python -m pip install 'boto3-stubs-lite[rds]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `boto3-stubs` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `boto3-stubs` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[rds]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed `boto3-stubs`

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `boto3-stubs[rds]` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[rds]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto3-stubs[rds]` in your environment:

```bash
python -m pip install 'boto3-stubs[rds]'`
```

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `boto3-stubs[rds]` in your environment:

```bash
python -m pip install 'boto3-stubs[rds]'
```

Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`RDSClient` provides annotations for `boto3.client("rds")`.

```python
from boto3.session import Session

from mypy_boto3_rds import RDSClient

client: RDSClient = Session().client("rds")

# now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_rds.paginator` module contains type annotations for all paginators.

```python
from boto3.session import Session

from mypy_boto3_rds import RDSClient
from mypy_boto3_rds.paginator import (
    DescribeCertificatesPaginator,
    DescribeDBClusterBacktracksPaginator,
    DescribeDBClusterEndpointsPaginator,
    DescribeDBClusterParameterGroupsPaginator,
    DescribeDBClusterParametersPaginator,
    DescribeDBClusterSnapshotsPaginator,
    DescribeDBClustersPaginator,
    DescribeDBEngineVersionsPaginator,
    DescribeDBInstanceAutomatedBackupsPaginator,
    DescribeDBInstancesPaginator,
    DescribeDBLogFilesPaginator,
    DescribeDBParameterGroupsPaginator,
    DescribeDBParametersPaginator,
    DescribeDBProxiesPaginator,
    DescribeDBProxyEndpointsPaginator,
    DescribeDBProxyTargetGroupsPaginator,
    DescribeDBProxyTargetsPaginator,
    DescribeDBSecurityGroupsPaginator,
    DescribeDBSnapshotsPaginator,
    DescribeDBSubnetGroupsPaginator,
    DescribeEngineDefaultClusterParametersPaginator,
    DescribeEngineDefaultParametersPaginator,
    DescribeEventSubscriptionsPaginator,
    DescribeEventsPaginator,
    DescribeExportTasksPaginator,
    DescribeGlobalClustersPaginator,
    DescribeOptionGroupOptionsPaginator,
    DescribeOptionGroupsPaginator,
    DescribeOrderableDBInstanceOptionsPaginator,
    DescribePendingMaintenanceActionsPaginator,
    DescribeReservedDBInstancesPaginator,
    DescribeReservedDBInstancesOfferingsPaginator,
    DescribeSourceRegionsPaginator,
    DownloadDBLogFilePortionPaginator,
)

client: RDSClient = Session().client("rds")

# Explicit type annotations are optional here
# Types should be correctly discovered by mypy and IDEs
describe_certificates_paginator: DescribeCertificatesPaginator = client.get_paginator(
    "describe_certificates"
)
describe_db_cluster_backtracks_paginator: DescribeDBClusterBacktracksPaginator = (
    client.get_paginator("describe_db_cluster_backtracks")
)
describe_db_cluster_endpoints_paginator: DescribeDBClusterEndpointsPaginator = client.get_paginator(
    "describe_db_cluster_endpoints"
)
describe_db_cluster_parameter_groups_paginator: DescribeDBClusterParameterGroupsPaginator = (
    client.get_paginator("describe_db_cluster_parameter_groups")
)
describe_db_cluster_parameters_paginator: DescribeDBClusterParametersPaginator = (
    client.get_paginator("describe_db_cluster_parameters")
)
describe_db_cluster_snapshots_paginator: DescribeDBClusterSnapshotsPaginator = client.get_paginator(
    "describe_db_cluster_snapshots"
)
describe_db_clusters_paginator: DescribeDBClustersPaginator = client.get_paginator(
    "describe_db_clusters"
)
describe_db_engine_versions_paginator: DescribeDBEngineVersionsPaginator = client.get_paginator(
    "describe_db_engine_versions"
)
describe_db_instance_automated_backups_paginator: DescribeDBInstanceAutomatedBackupsPaginator = (
    client.get_paginator("describe_db_instance_automated_backups")
)
describe_db_instances_paginator: DescribeDBInstancesPaginator = client.get_paginator(
    "describe_db_instances"
)
describe_db_log_files_paginator: DescribeDBLogFilesPaginator = client.get_paginator(
    "describe_db_log_files"
)
describe_db_parameter_groups_paginator: DescribeDBParameterGroupsPaginator = client.get_paginator(
    "describe_db_parameter_groups"
)
describe_db_parameters_paginator: DescribeDBParametersPaginator = client.get_paginator(
    "describe_db_parameters"
)
describe_db_proxies_paginator: DescribeDBProxiesPaginator = client.get_paginator(
    "describe_db_proxies"
)
describe_db_proxy_endpoints_paginator: DescribeDBProxyEndpointsPaginator = client.get_paginator(
    "describe_db_proxy_endpoints"
)
describe_db_proxy_target_groups_paginator: DescribeDBProxyTargetGroupsPaginator = (
    client.get_paginator("describe_db_proxy_target_groups")
)
describe_db_proxy_targets_paginator: DescribeDBProxyTargetsPaginator = client.get_paginator(
    "describe_db_proxy_targets"
)
describe_db_security_groups_paginator: DescribeDBSecurityGroupsPaginator = client.get_paginator(
    "describe_db_security_groups"
)
describe_db_snapshots_paginator: DescribeDBSnapshotsPaginator = client.get_paginator(
    "describe_db_snapshots"
)
describe_db_subnet_groups_paginator: DescribeDBSubnetGroupsPaginator = client.get_paginator(
    "describe_db_subnet_groups"
)
describe_engine_default_cluster_parameters_paginator: DescribeEngineDefaultClusterParametersPaginator = client.get_paginator(
    "describe_engine_default_cluster_parameters"
)
describe_engine_default_parameters_paginator: DescribeEngineDefaultParametersPaginator = (
    client.get_paginator("describe_engine_default_parameters")
)
describe_event_subscriptions_paginator: DescribeEventSubscriptionsPaginator = client.get_paginator(
    "describe_event_subscriptions"
)
describe_events_paginator: DescribeEventsPaginator = client.get_paginator("describe_events")
describe_export_tasks_paginator: DescribeExportTasksPaginator = client.get_paginator(
    "describe_export_tasks"
)
describe_global_clusters_paginator: DescribeGlobalClustersPaginator = client.get_paginator(
    "describe_global_clusters"
)
describe_option_group_options_paginator: DescribeOptionGroupOptionsPaginator = client.get_paginator(
    "describe_option_group_options"
)
describe_option_groups_paginator: DescribeOptionGroupsPaginator = client.get_paginator(
    "describe_option_groups"
)
describe_orderable_db_instance_options_paginator: DescribeOrderableDBInstanceOptionsPaginator = (
    client.get_paginator("describe_orderable_db_instance_options")
)
describe_pending_maintenance_actions_paginator: DescribePendingMaintenanceActionsPaginator = (
    client.get_paginator("describe_pending_maintenance_actions")
)
describe_reserved_db_instances_paginator: DescribeReservedDBInstancesPaginator = (
    client.get_paginator("describe_reserved_db_instances")
)
describe_reserved_db_instances_offerings_paginator: DescribeReservedDBInstancesOfferingsPaginator = client.get_paginator(
    "describe_reserved_db_instances_offerings"
)
describe_source_regions_paginator: DescribeSourceRegionsPaginator = client.get_paginator(
    "describe_source_regions"
)
download_db_log_file_portion_paginator: DownloadDBLogFilePortionPaginator = client.get_paginator(
    "download_db_log_file_portion"
)
```

<a id="waiters-annotations"></a>

### Waiters annotations

`mypy_boto3_rds.waiter` module contains type annotations for all waiters.

```python
from boto3.session import Session

from mypy_boto3_rds import RDSClient
from mypy_boto3_rds.waiter import (
    DBClusterAvailableWaiter,
    DBClusterDeletedWaiter,
    DBClusterSnapshotAvailableWaiter,
    DBClusterSnapshotDeletedWaiter,
    DBInstanceAvailableWaiter,
    DBInstanceDeletedWaiter,
    DBSnapshotAvailableWaiter,
    DBSnapshotCompletedWaiter,
    DBSnapshotDeletedWaiter,
)

client: RDSClient = Session().client("rds")

# Explicit type annotations are optional here
# Types should be correctly discovered by mypy and IDEs
db_cluster_available_waiter: DBClusterAvailableWaiter = client.get_waiter("db_cluster_available")
db_cluster_deleted_waiter: DBClusterDeletedWaiter = client.get_waiter("db_cluster_deleted")
db_cluster_snapshot_available_waiter: DBClusterSnapshotAvailableWaiter = client.get_waiter(
    "db_cluster_snapshot_available"
)
db_cluster_snapshot_deleted_waiter: DBClusterSnapshotDeletedWaiter = client.get_waiter(
    "db_cluster_snapshot_deleted"
)
db_instance_available_waiter: DBInstanceAvailableWaiter = client.get_waiter("db_instance_available")
db_instance_deleted_waiter: DBInstanceDeletedWaiter = client.get_waiter("db_instance_deleted")
db_snapshot_available_waiter: DBSnapshotAvailableWaiter = client.get_waiter("db_snapshot_available")
db_snapshot_completed_waiter: DBSnapshotCompletedWaiter = client.get_waiter("db_snapshot_completed")
db_snapshot_deleted_waiter: DBSnapshotDeletedWaiter = client.get_waiter("db_snapshot_deleted")
```

<a id="literals"></a>

### Literals

`mypy_boto3_rds.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_rds.literals import (
    ActivityStreamModeType,
    ActivityStreamPolicyStatusType,
    ActivityStreamStatusType,
    ApplyMethodType,
    AuditPolicyStateType,
    AuthSchemeType,
    AutomationModeType,
    CustomEngineVersionStatusType,
    DBClusterAvailableWaiterName,
    DBClusterDeletedWaiterName,
    DBClusterSnapshotAvailableWaiterName,
    DBClusterSnapshotDeletedWaiterName,
    DBInstanceAvailableWaiterName,
    DBInstanceDeletedWaiterName,
    DBProxyEndpointStatusType,
    DBProxyEndpointTargetRoleType,
    DBProxyStatusType,
    DBSnapshotAvailableWaiterName,
    DBSnapshotCompletedWaiterName,
    DBSnapshotDeletedWaiterName,
    DescribeCertificatesPaginatorName,
    DescribeDBClusterBacktracksPaginatorName,
    DescribeDBClusterEndpointsPaginatorName,
    DescribeDBClusterParameterGroupsPaginatorName,
    DescribeDBClusterParametersPaginatorName,
    DescribeDBClusterSnapshotsPaginatorName,
    DescribeDBClustersPaginatorName,
    DescribeDBEngineVersionsPaginatorName,
    DescribeDBInstanceAutomatedBackupsPaginatorName,
    DescribeDBInstancesPaginatorName,
    DescribeDBLogFilesPaginatorName,
    DescribeDBParameterGroupsPaginatorName,
    DescribeDBParametersPaginatorName,
    DescribeDBProxiesPaginatorName,
    DescribeDBProxyEndpointsPaginatorName,
    DescribeDBProxyTargetGroupsPaginatorName,
    DescribeDBProxyTargetsPaginatorName,
    DescribeDBSecurityGroupsPaginatorName,
    DescribeDBSnapshotsPaginatorName,
    DescribeDBSubnetGroupsPaginatorName,
    DescribeEngineDefaultClusterParametersPaginatorName,
    DescribeEngineDefaultParametersPaginatorName,
    DescribeEventSubscriptionsPaginatorName,
    DescribeEventsPaginatorName,
    DescribeExportTasksPaginatorName,
    DescribeGlobalClustersPaginatorName,
    DescribeOptionGroupOptionsPaginatorName,
    DescribeOptionGroupsPaginatorName,
    DescribeOrderableDBInstanceOptionsPaginatorName,
    DescribePendingMaintenanceActionsPaginatorName,
    DescribeReservedDBInstancesOfferingsPaginatorName,
    DescribeReservedDBInstancesPaginatorName,
    DescribeSourceRegionsPaginatorName,
    DownloadDBLogFilePortionPaginatorName,
    EngineFamilyType,
    ExportSourceTypeType,
    FailoverStatusType,
    IAMAuthModeType,
    ReplicaModeType,
    SourceTypeType,
    TargetHealthReasonType,
    TargetRoleType,
    TargetStateType,
    TargetTypeType,
    WriteForwardingStatusType,
    RDSServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    WaiterName,
    RegionName,
)


def check_value(value: ActivityStreamModeType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_rds.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_rds.type_defs import (
    AccountQuotaTypeDef,
    ResponseMetadataTypeDef,
    AddRoleToDBClusterMessageRequestTypeDef,
    AddRoleToDBInstanceMessageRequestTypeDef,
    AddSourceIdentifierToSubscriptionMessageRequestTypeDef,
    EventSubscriptionTypeDef,
    TagTypeDef,
    ApplyPendingMaintenanceActionMessageRequestTypeDef,
    AuthorizeDBSecurityGroupIngressMessageRequestTypeDef,
    AvailabilityZoneTypeDef,
    AvailableProcessorFeatureTypeDef,
    BacktrackDBClusterMessageRequestTypeDef,
    CancelExportTaskMessageRequestTypeDef,
    CertificateTypeDef,
    CharacterSetTypeDef,
    ClientGenerateDbAuthTokenRequestTypeDef,
    CloudwatchLogsExportConfigurationTypeDef,
    PendingCloudwatchLogsExportsTypeDef,
    ConnectionPoolConfigurationInfoTypeDef,
    ConnectionPoolConfigurationTypeDef,
    DBClusterParameterGroupTypeDef,
    DBParameterGroupTypeDef,
    ScalingConfigurationTypeDef,
    ServerlessV2ScalingConfigurationTypeDef,
    ProcessorFeatureTypeDef,
    DBProxyEndpointTypeDef,
    UserAuthConfigTypeDef,
    CreateGlobalClusterMessageRequestTypeDef,
    DBClusterBacktrackTypeDef,
    DBClusterEndpointTypeDef,
    DBClusterMemberTypeDef,
    DBClusterOptionGroupStatusTypeDef,
    ParameterTypeDef,
    DBClusterRoleTypeDef,
    DBClusterSnapshotAttributeTypeDef,
    DomainMembershipTypeDef,
    ScalingConfigurationInfoTypeDef,
    ServerlessV2ScalingConfigurationInfoTypeDef,
    VpcSecurityGroupMembershipTypeDef,
    TimezoneTypeDef,
    UpgradeTargetTypeDef,
    DBInstanceAutomatedBackupsReplicationTypeDef,
    RestoreWindowTypeDef,
    DBInstanceRoleTypeDef,
    DBInstanceStatusInfoTypeDef,
    DBParameterGroupStatusTypeDef,
    DBSecurityGroupMembershipTypeDef,
    EndpointTypeDef,
    OptionGroupMembershipTypeDef,
    TargetHealthTypeDef,
    UserAuthConfigInfoTypeDef,
    EC2SecurityGroupTypeDef,
    IPRangeTypeDef,
    DBSnapshotAttributeTypeDef,
    DeleteCustomDBEngineVersionMessageRequestTypeDef,
    DeleteDBClusterEndpointMessageRequestTypeDef,
    DeleteDBClusterMessageRequestTypeDef,
    DeleteDBClusterParameterGroupMessageRequestTypeDef,
    DeleteDBClusterSnapshotMessageRequestTypeDef,
    DeleteDBInstanceAutomatedBackupMessageRequestTypeDef,
    DeleteDBInstanceMessageRequestTypeDef,
    DeleteDBParameterGroupMessageRequestTypeDef,
    DeleteDBProxyEndpointRequestRequestTypeDef,
    DeleteDBProxyRequestRequestTypeDef,
    DeleteDBSecurityGroupMessageRequestTypeDef,
    DeleteDBSnapshotMessageRequestTypeDef,
    DeleteDBSubnetGroupMessageRequestTypeDef,
    DeleteEventSubscriptionMessageRequestTypeDef,
    DeleteGlobalClusterMessageRequestTypeDef,
    DeleteOptionGroupMessageRequestTypeDef,
    DeregisterDBProxyTargetsRequestRequestTypeDef,
    FilterTypeDef,
    PaginatorConfigTypeDef,
    DescribeDBClusterSnapshotAttributesMessageRequestTypeDef,
    WaiterConfigTypeDef,
    DescribeDBLogFilesDetailsTypeDef,
    DescribeDBSnapshotAttributesMessageRequestTypeDef,
    DescribeValidDBInstanceModificationsMessageRequestTypeDef,
    DoubleRangeTypeDef,
    DownloadDBLogFilePortionMessageRequestTypeDef,
    EventCategoriesMapTypeDef,
    EventTypeDef,
    ExportTaskTypeDef,
    FailoverDBClusterMessageRequestTypeDef,
    FailoverGlobalClusterMessageRequestTypeDef,
    FailoverStateTypeDef,
    GlobalClusterMemberTypeDef,
    MinimumEngineVersionPerAllowedValueTypeDef,
    ModifyActivityStreamRequestRequestTypeDef,
    ModifyCertificatesMessageRequestTypeDef,
    ModifyCurrentDBClusterCapacityMessageRequestTypeDef,
    ModifyCustomDBEngineVersionMessageRequestTypeDef,
    ModifyDBClusterEndpointMessageRequestTypeDef,
    ModifyDBClusterSnapshotAttributeMessageRequestTypeDef,
    ModifyDBProxyEndpointRequestRequestTypeDef,
    ModifyDBSnapshotAttributeMessageRequestTypeDef,
    ModifyDBSnapshotMessageRequestTypeDef,
    ModifyDBSubnetGroupMessageRequestTypeDef,
    ModifyEventSubscriptionMessageRequestTypeDef,
    ModifyGlobalClusterMessageRequestTypeDef,
    OptionSettingTypeDef,
    OptionVersionTypeDef,
    OutpostTypeDef,
    PendingMaintenanceActionTypeDef,
    PromoteReadReplicaDBClusterMessageRequestTypeDef,
    PromoteReadReplicaMessageRequestTypeDef,
    RangeTypeDef,
    RebootDBClusterMessageRequestTypeDef,
    RebootDBInstanceMessageRequestTypeDef,
    RecurringChargeTypeDef,
    RegisterDBProxyTargetsRequestRequestTypeDef,
    RemoveFromGlobalClusterMessageRequestTypeDef,
    RemoveRoleFromDBClusterMessageRequestTypeDef,
    RemoveRoleFromDBInstanceMessageRequestTypeDef,
    RemoveSourceIdentifierFromSubscriptionMessageRequestTypeDef,
    RemoveTagsFromResourceMessageRequestTypeDef,
    RevokeDBSecurityGroupIngressMessageRequestTypeDef,
    SourceRegionTypeDef,
    StartActivityStreamRequestRequestTypeDef,
    StartDBClusterMessageRequestTypeDef,
    StartDBInstanceAutomatedBackupsReplicationMessageRequestTypeDef,
    StartDBInstanceMessageRequestTypeDef,
    StartExportTaskMessageRequestTypeDef,
    StopActivityStreamRequestRequestTypeDef,
    StopDBClusterMessageRequestTypeDef,
    StopDBInstanceAutomatedBackupsReplicationMessageRequestTypeDef,
    StopDBInstanceMessageRequestTypeDef,
    SwitchoverReadReplicaMessageRequestTypeDef,
    AccountAttributesMessageTypeDef,
    DBClusterBacktrackResponseMetadataTypeDef,
    DBClusterCapacityInfoTypeDef,
    DBClusterEndpointResponseMetadataTypeDef,
    DBClusterParameterGroupNameMessageTypeDef,
    DBParameterGroupNameMessageTypeDef,
    DownloadDBLogFilePortionDetailsTypeDef,
    EmptyResponseMetadataTypeDef,
    ExportTaskResponseMetadataTypeDef,
    ModifyActivityStreamResponseTypeDef,
    StartActivityStreamResponseTypeDef,
    StopActivityStreamResponseTypeDef,
    AddSourceIdentifierToSubscriptionResultTypeDef,
    CreateEventSubscriptionResultTypeDef,
    DeleteEventSubscriptionResultTypeDef,
    EventSubscriptionsMessageTypeDef,
    ModifyEventSubscriptionResultTypeDef,
    RemoveSourceIdentifierFromSubscriptionResultTypeDef,
    AddTagsToResourceMessageRequestTypeDef,
    CopyDBClusterParameterGroupMessageRequestTypeDef,
    CopyDBClusterSnapshotMessageRequestTypeDef,
    CopyDBParameterGroupMessageRequestTypeDef,
    CopyDBSnapshotMessageRequestTypeDef,
    CopyOptionGroupMessageRequestTypeDef,
    CreateCustomDBEngineVersionMessageRequestTypeDef,
    CreateDBClusterEndpointMessageRequestTypeDef,
    CreateDBClusterParameterGroupMessageRequestTypeDef,
    CreateDBClusterSnapshotMessageRequestTypeDef,
    CreateDBParameterGroupMessageRequestTypeDef,
    CreateDBProxyEndpointRequestRequestTypeDef,
    CreateDBSecurityGroupMessageRequestTypeDef,
    CreateDBSnapshotMessageRequestTypeDef,
    CreateDBSubnetGroupMessageRequestTypeDef,
    CreateEventSubscriptionMessageRequestTypeDef,
    CreateOptionGroupMessageRequestTypeDef,
    DBClusterSnapshotTypeDef,
    PurchaseReservedDBInstancesOfferingMessageRequestTypeDef,
    TagListMessageTypeDef,
    OrderableDBInstanceOptionTypeDef,
    CertificateMessageTypeDef,
    ModifyCertificatesResultTypeDef,
    ClusterPendingModifiedValuesTypeDef,
    DBProxyTargetGroupTypeDef,
    ModifyDBProxyTargetGroupRequestRequestTypeDef,
    CopyDBClusterParameterGroupResultTypeDef,
    CreateDBClusterParameterGroupResultTypeDef,
    DBClusterParameterGroupsMessageTypeDef,
    CopyDBParameterGroupResultTypeDef,
    CreateDBParameterGroupResultTypeDef,
    DBParameterGroupsMessageTypeDef,
    CreateDBClusterMessageRequestTypeDef,
    ModifyDBClusterMessageRequestTypeDef,
    RestoreDBClusterFromS3MessageRequestTypeDef,
    RestoreDBClusterFromSnapshotMessageRequestTypeDef,
    RestoreDBClusterToPointInTimeMessageRequestTypeDef,
    CreateDBInstanceMessageRequestTypeDef,
    CreateDBInstanceReadReplicaMessageRequestTypeDef,
    DBSnapshotTypeDef,
    ModifyDBInstanceMessageRequestTypeDef,
    PendingModifiedValuesTypeDef,
    RestoreDBInstanceFromDBSnapshotMessageRequestTypeDef,
    RestoreDBInstanceFromS3MessageRequestTypeDef,
    RestoreDBInstanceToPointInTimeMessageRequestTypeDef,
    CreateDBProxyEndpointResponseTypeDef,
    DeleteDBProxyEndpointResponseTypeDef,
    DescribeDBProxyEndpointsResponseTypeDef,
    ModifyDBProxyEndpointResponseTypeDef,
    CreateDBProxyRequestRequestTypeDef,
    ModifyDBProxyRequestRequestTypeDef,
    DBClusterBacktrackMessageTypeDef,
    DBClusterEndpointMessageTypeDef,
    DBClusterParameterGroupDetailsTypeDef,
    DBParameterGroupDetailsTypeDef,
    EngineDefaultsTypeDef,
    ModifyDBClusterParameterGroupMessageRequestTypeDef,
    ModifyDBParameterGroupMessageRequestTypeDef,
    ResetDBClusterParameterGroupMessageRequestTypeDef,
    ResetDBParameterGroupMessageRequestTypeDef,
    DBClusterSnapshotAttributesResultTypeDef,
    DBEngineVersionResponseMetadataTypeDef,
    DBEngineVersionTypeDef,
    DBInstanceAutomatedBackupTypeDef,
    DBProxyTargetTypeDef,
    DBProxyTypeDef,
    DBSecurityGroupTypeDef,
    DBSnapshotAttributesResultTypeDef,
    DescribeCertificatesMessageRequestTypeDef,
    DescribeDBClusterBacktracksMessageRequestTypeDef,
    DescribeDBClusterEndpointsMessageRequestTypeDef,
    DescribeDBClusterParameterGroupsMessageRequestTypeDef,
    DescribeDBClusterParametersMessageRequestTypeDef,
    DescribeDBClusterSnapshotsMessageRequestTypeDef,
    DescribeDBClustersMessageRequestTypeDef,
    DescribeDBEngineVersionsMessageRequestTypeDef,
    DescribeDBInstanceAutomatedBackupsMessageRequestTypeDef,
    DescribeDBInstancesMessageRequestTypeDef,
    DescribeDBLogFilesMessageRequestTypeDef,
    DescribeDBParameterGroupsMessageRequestTypeDef,
    DescribeDBParametersMessageRequestTypeDef,
    DescribeDBProxiesRequestRequestTypeDef,
    DescribeDBProxyEndpointsRequestRequestTypeDef,
    DescribeDBProxyTargetGroupsRequestRequestTypeDef,
    DescribeDBProxyTargetsRequestRequestTypeDef,
    DescribeDBSecurityGroupsMessageRequestTypeDef,
    DescribeDBSnapshotsMessageRequestTypeDef,
    DescribeDBSubnetGroupsMessageRequestTypeDef,
    DescribeEngineDefaultClusterParametersMessageRequestTypeDef,
    DescribeEngineDefaultParametersMessageRequestTypeDef,
    DescribeEventCategoriesMessageRequestTypeDef,
    DescribeEventSubscriptionsMessageRequestTypeDef,
    DescribeEventsMessageRequestTypeDef,
    DescribeExportTasksMessageRequestTypeDef,
    DescribeGlobalClustersMessageRequestTypeDef,
    DescribeOptionGroupOptionsMessageRequestTypeDef,
    DescribeOptionGroupsMessageRequestTypeDef,
    DescribeOrderableDBInstanceOptionsMessageRequestTypeDef,
    DescribePendingMaintenanceActionsMessageRequestTypeDef,
    DescribeReservedDBInstancesMessageRequestTypeDef,
    DescribeReservedDBInstancesOfferingsMessageRequestTypeDef,
    DescribeSourceRegionsMessageRequestTypeDef,
    ListTagsForResourceMessageRequestTypeDef,
    DescribeCertificatesMessageDescribeCertificatesPaginateTypeDef,
    DescribeDBClusterBacktracksMessageDescribeDBClusterBacktracksPaginateTypeDef,
    DescribeDBClusterEndpointsMessageDescribeDBClusterEndpointsPaginateTypeDef,
    DescribeDBClusterParameterGroupsMessageDescribeDBClusterParameterGroupsPaginateTypeDef,
    DescribeDBClusterParametersMessageDescribeDBClusterParametersPaginateTypeDef,
    DescribeDBClusterSnapshotsMessageDescribeDBClusterSnapshotsPaginateTypeDef,
    DescribeDBClustersMessageDescribeDBClustersPaginateTypeDef,
    DescribeDBEngineVersionsMessageDescribeDBEngineVersionsPaginateTypeDef,
    DescribeDBInstanceAutomatedBackupsMessageDescribeDBInstanceAutomatedBackupsPaginateTypeDef,
    DescribeDBInstancesMessageDescribeDBInstancesPaginateTypeDef,
    DescribeDBLogFilesMessageDescribeDBLogFilesPaginateTypeDef,
    DescribeDBParameterGroupsMessageDescribeDBParameterGroupsPaginateTypeDef,
    DescribeDBParametersMessageDescribeDBParametersPaginateTypeDef,
    DescribeDBProxiesRequestDescribeDBProxiesPaginateTypeDef,
    DescribeDBProxyEndpointsRequestDescribeDBProxyEndpointsPaginateTypeDef,
    DescribeDBProxyTargetGroupsRequestDescribeDBProxyTargetGroupsPaginateTypeDef,
    DescribeDBProxyTargetsRequestDescribeDBProxyTargetsPaginateTypeDef,
    DescribeDBSecurityGroupsMessageDescribeDBSecurityGroupsPaginateTypeDef,
    DescribeDBSnapshotsMessageDescribeDBSnapshotsPaginateTypeDef,
    DescribeDBSubnetGroupsMessageDescribeDBSubnetGroupsPaginateTypeDef,
    DescribeEngineDefaultClusterParametersMessageDescribeEngineDefaultClusterParametersPaginateTypeDef,
    DescribeEngineDefaultParametersMessageDescribeEngineDefaultParametersPaginateTypeDef,
    DescribeEventSubscriptionsMessageDescribeEventSubscriptionsPaginateTypeDef,
    DescribeEventsMessageDescribeEventsPaginateTypeDef,
    DescribeExportTasksMessageDescribeExportTasksPaginateTypeDef,
    DescribeGlobalClustersMessageDescribeGlobalClustersPaginateTypeDef,
    DescribeOptionGroupOptionsMessageDescribeOptionGroupOptionsPaginateTypeDef,
    DescribeOptionGroupsMessageDescribeOptionGroupsPaginateTypeDef,
    DescribeOrderableDBInstanceOptionsMessageDescribeOrderableDBInstanceOptionsPaginateTypeDef,
    DescribePendingMaintenanceActionsMessageDescribePendingMaintenanceActionsPaginateTypeDef,
    DescribeReservedDBInstancesMessageDescribeReservedDBInstancesPaginateTypeDef,
    DescribeReservedDBInstancesOfferingsMessageDescribeReservedDBInstancesOfferingsPaginateTypeDef,
    DescribeSourceRegionsMessageDescribeSourceRegionsPaginateTypeDef,
    DownloadDBLogFilePortionMessageDownloadDBLogFilePortionPaginateTypeDef,
    DescribeDBClusterSnapshotsMessageDBClusterSnapshotAvailableWaitTypeDef,
    DescribeDBClusterSnapshotsMessageDBClusterSnapshotDeletedWaitTypeDef,
    DescribeDBClustersMessageDBClusterAvailableWaitTypeDef,
    DescribeDBClustersMessageDBClusterDeletedWaitTypeDef,
    DescribeDBInstancesMessageDBInstanceAvailableWaitTypeDef,
    DescribeDBInstancesMessageDBInstanceDeletedWaitTypeDef,
    DescribeDBSnapshotsMessageDBSnapshotAvailableWaitTypeDef,
    DescribeDBSnapshotsMessageDBSnapshotCompletedWaitTypeDef,
    DescribeDBSnapshotsMessageDBSnapshotDeletedWaitTypeDef,
    DescribeDBLogFilesResponseTypeDef,
    EventCategoriesMessageTypeDef,
    EventsMessageTypeDef,
    ExportTasksMessageTypeDef,
    GlobalClusterTypeDef,
    OptionGroupOptionSettingTypeDef,
    OptionConfigurationTypeDef,
    OptionTypeDef,
    SubnetTypeDef,
    ResourcePendingMaintenanceActionsTypeDef,
    ValidStorageOptionsTypeDef,
    ReservedDBInstanceTypeDef,
    ReservedDBInstancesOfferingTypeDef,
    SourceRegionMessageTypeDef,
    CopyDBClusterSnapshotResultTypeDef,
    CreateDBClusterSnapshotResultTypeDef,
    DBClusterSnapshotMessageTypeDef,
    DeleteDBClusterSnapshotResultTypeDef,
    OrderableDBInstanceOptionsMessageTypeDef,
    DBClusterTypeDef,
    DescribeDBProxyTargetGroupsResponseTypeDef,
    ModifyDBProxyTargetGroupResponseTypeDef,
    CopyDBSnapshotResultTypeDef,
    CreateDBSnapshotResultTypeDef,
    DBSnapshotMessageTypeDef,
    DeleteDBSnapshotResultTypeDef,
    ModifyDBSnapshotResultTypeDef,
    DescribeEngineDefaultClusterParametersResultTypeDef,
    DescribeEngineDefaultParametersResultTypeDef,
    DescribeDBClusterSnapshotAttributesResultTypeDef,
    ModifyDBClusterSnapshotAttributeResultTypeDef,
    DBEngineVersionMessageTypeDef,
    DBInstanceAutomatedBackupMessageTypeDef,
    DeleteDBInstanceAutomatedBackupResultTypeDef,
    StartDBInstanceAutomatedBackupsReplicationResultTypeDef,
    StopDBInstanceAutomatedBackupsReplicationResultTypeDef,
    DescribeDBProxyTargetsResponseTypeDef,
    RegisterDBProxyTargetsResponseTypeDef,
    CreateDBProxyResponseTypeDef,
    DeleteDBProxyResponseTypeDef,
    DescribeDBProxiesResponseTypeDef,
    ModifyDBProxyResponseTypeDef,
    AuthorizeDBSecurityGroupIngressResultTypeDef,
    CreateDBSecurityGroupResultTypeDef,
    DBSecurityGroupMessageTypeDef,
    RevokeDBSecurityGroupIngressResultTypeDef,
    DescribeDBSnapshotAttributesResultTypeDef,
    ModifyDBSnapshotAttributeResultTypeDef,
    CreateGlobalClusterResultTypeDef,
    DeleteGlobalClusterResultTypeDef,
    FailoverGlobalClusterResultTypeDef,
    GlobalClustersMessageTypeDef,
    ModifyGlobalClusterResultTypeDef,
    RemoveFromGlobalClusterResultTypeDef,
    OptionGroupOptionTypeDef,
    ModifyOptionGroupMessageRequestTypeDef,
    OptionGroupTypeDef,
    DBSubnetGroupTypeDef,
    ApplyPendingMaintenanceActionResultTypeDef,
    PendingMaintenanceActionsMessageTypeDef,
    ValidDBInstanceModificationsMessageTypeDef,
    PurchaseReservedDBInstancesOfferingResultTypeDef,
    ReservedDBInstanceMessageTypeDef,
    ReservedDBInstancesOfferingMessageTypeDef,
    CreateDBClusterResultTypeDef,
    DBClusterMessageTypeDef,
    DeleteDBClusterResultTypeDef,
    FailoverDBClusterResultTypeDef,
    ModifyDBClusterResultTypeDef,
    PromoteReadReplicaDBClusterResultTypeDef,
    RebootDBClusterResultTypeDef,
    RestoreDBClusterFromS3ResultTypeDef,
    RestoreDBClusterFromSnapshotResultTypeDef,
    RestoreDBClusterToPointInTimeResultTypeDef,
    StartDBClusterResultTypeDef,
    StopDBClusterResultTypeDef,
    OptionGroupOptionsMessageTypeDef,
    CopyOptionGroupResultTypeDef,
    CreateOptionGroupResultTypeDef,
    ModifyOptionGroupResultTypeDef,
    OptionGroupsTypeDef,
    CreateDBSubnetGroupResultTypeDef,
    DBInstanceTypeDef,
    DBSubnetGroupMessageTypeDef,
    ModifyDBSubnetGroupResultTypeDef,
    DescribeValidDBInstanceModificationsResultTypeDef,
    CreateDBInstanceReadReplicaResultTypeDef,
    CreateDBInstanceResultTypeDef,
    DBInstanceMessageTypeDef,
    DeleteDBInstanceResultTypeDef,
    ModifyDBInstanceResultTypeDef,
    PromoteReadReplicaResultTypeDef,
    RebootDBInstanceResultTypeDef,
    RestoreDBInstanceFromDBSnapshotResultTypeDef,
    RestoreDBInstanceFromS3ResultTypeDef,
    RestoreDBInstanceToPointInTimeResultTypeDef,
    StartDBInstanceResultTypeDef,
    StopDBInstanceResultTypeDef,
    SwitchoverReadReplicaResultTypeDef,
)


def get_structure() -> AccountQuotaTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for `boto3`
updates. It delivers a drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`mypy-boto3-rds` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[boto3 docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rds/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
